@@ -9,10 +9,10 @@
 
 namespace apolloron {
 
-#define UNICODE_GBK_TABLE_MAX 23934
+#define UNICODE_GBK_TABLE_MAX 33280
 
-extern const short int index_unicode_gbk[256];
-extern const unsigned char unicode_gbk[UNICODE_GBK_TABLE_MAX][3];
+extern const int index_unicode_gbk[256];
+extern const unsigned char unicode_gbk[UNICODE_GBK_TABLE_MAX][2];
 
 
 } // namespace apolloron
