@@ -60,7 +60,7 @@ String valueToString(double value) {
 #if defined(_MSC_VER) && defined(__STDC_SECURE_LIB__) // Use secure version with visual studio 2005 to avoid warning. 
     sprintf_s(buffer, sizeof(buffer), "%#.16g", value);
 #else
-    sprintf(buffer, "%#.16g", value);
+    ::snprintf(buffer, sizeof(buffer), "%#.16g", value);
 #endif
     char* ch = buffer + strlen(buffer) - 1;
     if(*ch != '0') return buffer;  // nothing to truncate, so save time
@@ -143,7 +143,7 @@ String valueToQuotedString(const char *value) {
             default:
                 if(isControlCharacter(*c)) {
                     char oss[10];
-                    sprintf(oss, "\\u%04x", (int)(*c));
+                    ::snprintf(oss, sizeof(oss), "\\u%04x", (int)(*c));
                     result += oss;
                 } else {
                     result += *c;
